function wheel2(seconds, spokes, frame_rate)
%WHEEL2 Spinning wheel with linearly increasing angular velocity
%  WHEEL(SECONDS, SPOKES, FRAME_RATE) generates an AVI movie of a spinning wheel
%  with linearly increasing angular velocity, the number of spokes specified by
%  SPOKES, video capture rate specified by FRAME_RATE, and total movie duration
%  specified by SECONDS. 
%
%  The resulting AVI file is named "wheel.avi" and is saved to the current
%  directory.
%
%  The default values for each of the inputs are as follows:
%    SECONDS:          10
%    SPOKES:           12
%    FRAME_RATE:       24 frames/sec
%
%  Feel free to experiment and see the effects of video aliasing for
%  yourself.
%
% Created by: Eric Weiss
% Last Modified: by Michael Siracusa 2/6/07, 11:00pm

file = 'wheel.avi';

% Input argument checking: use defaults?
%---------------------------------------
if nargin < 3
    frame_rate = 24;
end;
if nargin < 2
    spokes = 12;
end;
if nargin == 0
    seconds = 10;
end;

% Create images
%--------------
periods = 2;
dangle = periods*[1:ceil(seconds*frame_rate)]*pi/spokes/(seconds*frame_rate);

mov = avifile(file,'fps',frame_rate);  % open AVI movie file
fprintf('Recording AVI movie file %s...\n',file);
F = figure;
set(F,'Color',[1 1 1]);
for i = 1:ceil(seconds*frame_rate)  % capture individual movie frames
    draw_wheel( spokes, dangle(i)*(i-1));
    frame = getframe(F);
    mov = addframe(mov,frame);
end;
mov = close(mov);
close(F);
fprintf('AVI movie file %s has been recorded.\n\n',file);


% Function DRAW_WHEEL: draws the wheel
%-------------------------------------
function draw_wheel(spokes, angle)

wheel_width = 10;
spoke_width = 3;

hold off;

% Draw outer circle. Wrapping around twice removes 
% some endpoint drawing issues
N = 200;
t =[0:N 0:N]*2*pi/N;
plot(cos(t),sin(t),'k','lineWidth',wheel_width); hold on;

% Draw spokes
spoke_angle = 2*pi / spokes;
for i = 1:spokes
    x = [0 cos(angle+(i-1)*spoke_angle)];
    y = [0 -sin(angle+(i-1)*spoke_angle)];
    plot(x,y,'k','lineWidth',spoke_width);
end;

axis([-1 1 -1 1]*1.25);
axis off; axis square; grid off;